import { defineStore } from 'pinia'
import { computed, MaybeRefOrGetter, toValue } from 'vue'
import { useCurrentRadioSettings } from '@/stores/radio-settings'

type Input = {
  uri: string
  label: string
  description?: string
}

export function useInput(uri: MaybeRefOrGetter<string>) {
  const playoutStore = usePlayoutStore()
  return computed(() => playoutStore.inputs.find((i) => i.uri === toValue(uri)) ?? null)
}

export const usePlayoutStore = defineStore('playout', () => {
  const radioSettings = useCurrentRadioSettings()

  const inputs = computed<Input[]>(() => {
    const inputs = Object.entries(radioSettings.value?.playout?.lineInChannels ?? {})
    return inputs.map(([id, label]) => ({ uri: `line://${id}`, label }))
  })

  return {
    inputs,
  }
})
